#!/bin/bash
PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/bin

# 090114  14:22  script to log the date and cell id.
# can be used later to combine location and cell id,
# if the clock is syncronized to gpsd while logging.

MY_PATH=/home/root/scripts/gps

log_gsm()
{
SUFFIX=`date +%s`
echo "${SUFFIX}" > "${MY_PATH}"/tables/suffix.txt

while true; do

 # get_cell_id will give info on the current used gsm cell and contains the following line:
 #+CREG: 2,5,"00BE","5F99"+CREG: 2,5,"00BE","5F99"\ M

 RAW_CELL=`"${MY_PATH}"/scripts/get_cell_id.sh 2>&1 | grep +CREG:`

 LAC_HEX=`echo "${RAW_CELL}" | awk -F'"' '{ print $2}' | sed 's/.*/0x&/'`
 LAC=`printf "%d\n" "${LAC_HEX}"`
 
 CELLID_HEX=`echo "${RAW_CELL}" | awk -F'"' '{print $4}' | sed 's/.*/0x&/'`
 CELLID=`printf "%d\n" "${CELLID_HEX}"`

 #get_mcc_mnc will get the curent country and network code and contains the following line:
 #%EM: 3,50,204,016,200338741%EM: 3,50,204,016,200338741\ M

 RAW_COUNTRY=`"${MY_PATH}"/scripts/get_mcc_mnc.sh 2>&1 | grep '%EM:'`
 COUNTRY=`echo "${RAW_COUNTRY}" | awk -F"," '{print $3}'`
 NETWORK=`echo "${RAW_COUNTRY}" | awk -F"," '{print $4}'`

 # we need the date and time of the sample, so we can match it to our location
 # we record with gpspipe and convert with gpsbabel to gpx format.
 # the time stamp is in the same format as the gpx file, for easy parsing
 UTC_DATE=`date -u +%Y-%m-%dT%H:%M:%SZ`

 # if we were able to obtain a cell id we log it to a file for later use
 # i generate an URL, so you can cut and paste it in a browser and check your location with the location
 # in the opencellid database.

 if test "${LAC}" -a "${CELLID}" -a "${COUNTRY}" -a "${NETWORK}"; then
  echo "${UTC_DATE}" 'http://www.opencellid.org/cell/get?mcc='"${COUNTRY}"'&mnc='"${NETWORK}"'&cellid='"${CELLID}"'&lac='"${LAC}" >> "${MY_PATH}"/tables/cell_ids_"${SUFFIX}"
 fi

 sleep 60

done
}

case "$1" in
 start)
  log_gsm &
  echo $! > /var/run/log_gsm
  ;;
 stop)
  if test -s /var/run/log_gsm; then
   LOG_GSM_PID=`cat /var/run/log_gsm`
   if ps -fp "${LOG_GSM_PID}" | grep harvest_cell_id >/dev/null 2>&1; then
    kill "${LOG_GSM_PID}"
   fi
  fi
  ;;
esac

